Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(303)

Unified Diff: services/ui/ws/frame_generator.h

Issue 2369793002: WIP: Propagate SurfaceID up window tree hierarchy
Patch Set: Fix input events: EventDispatcher ignores container windows Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/ws/display_manager.cc ('k') | services/ui/ws/frame_generator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/ws/frame_generator.h
diff --git a/services/ui/ws/frame_generator.h b/services/ui/ws/frame_generator.h
index 00b296a9eaf960b1f3e5ffd115efceae97d957da..d28cfa9c2a1b78ca35c5b2313aced37a03eb14f7 100644
--- a/services/ui/ws/frame_generator.h
+++ b/services/ui/ws/frame_generator.h
@@ -24,8 +24,10 @@ class GpuChannelHost;
namespace ui {
+namespace surfaces {
+class CompositorFrameSink;
class DisplayCompositor;
-class SurfacesState;
+}
namespace ws {
@@ -37,11 +39,11 @@ class FrameGeneratorDelegate;
class ServerWindow;
// Responsible for redrawing the display in response to the redraw requests by
// submitting CompositorFrames to the owned DisplayCompositor.
class FrameGenerator {
public:
FrameGenerator(FrameGeneratorDelegate* delegate,
- scoped_refptr<SurfacesState> surfaces_state);
+ scoped_refptr<surfaces::DisplayCompositor> display_compositor);
virtual ~FrameGenerator();
void OnGpuChannelEstablished(scoped_refptr<gpu::GpuChannelHost> gpu_channel);
@@ -64,7 +66,7 @@ class FrameGenerator {
// http://crbug.com/533042
void Draw();
// This is called after the DisplayCompositor has completed generating a new
// frame for the display. TODO(fsamuel): Idle time processing should happen
// here if there is budget for it.
void DidDraw();
@@ -82,10 +84,10 @@ class FrameGenerator {
bool* may_contain_video) const;
FrameGeneratorDelegate* delegate_;
- scoped_refptr<SurfacesState> surfaces_state_;
+ scoped_refptr<surfaces::DisplayCompositor> display_compositor_;
scoped_refptr<gpu::GpuChannelHost> gpu_channel_;
- std::unique_ptr<DisplayCompositor> display_compositor_;
+ std::unique_ptr<surfaces::CompositorFrameSink> compositor_frame_sink_;
gfx::AcceleratedWidget widget_ = gfx::kNullAcceleratedWidget;
// The region that needs to be redrawn next time the compositor frame is
« no previous file with comments | « services/ui/ws/display_manager.cc ('k') | services/ui/ws/frame_generator.cc » ('j') | no next file with comments »
@@ -37,11 +39,11 @@ class FrameGeneratorDelegate;
class ServerWindow;
// Responsible for redrawing the display in response to the redraw requests by
-// submitting CompositorFrames to the owned DisplayCompositor.
+// submitting CompositorFrames to the owned CompositorFrameSink.
class FrameGenerator {
public:
@@ -64,7 +66,7 @@ class FrameGenerator {
// http://crbug.com/533042
void Draw();
- // This is called after the DisplayCompositor has completed generating a new
+ // This is called after the CompositorFrameSink has completed generating a new
// frame for the display. TODO(fsamuel): Idle time processing should happen
// here if there is budget for it.

Powered by Google App Engine
This is Rietveld 408576698